"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.request = void 0;
const axios_1 = require("axios");
const ErrorMessages_1 = require("./ErrorMessages");
function request(method, token, url, data) {
    return __awaiter(this, void 0, void 0, function* () {
        if (!url) {
            throw ({ message: 'Empty request url' });
        }
        else {
            const header = {
                headers: {
                    token: token
                }
            };
            switch (method) {
                case "GET":
                    return yield get(url, header);
                case "UPDATE":
                    break;
                case "POST":
                    if (data)
                        return yield post(url, header, data);
                case "DELETE":
                    break;
            }
        }
    });
}
exports.request = request;
function get(url, header) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            const respons = yield axios_1.default.get(url, header);
            return respons;
        }
        catch (error) {
            let errorMsg = '';
            if (!error.response) {
                errorMsg = ErrorMessages_1.Errors.noInternet;
            }
            else {
                if (!error.response.data.message) {
                    errorMsg = ErrorMessages_1.Errors.serverError;
                }
                else {
                    errorMsg = error.response.data.message;
                }
            }
            throw new Error(errorMsg);
        }
    });
}
function post(url, header, data) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            const respons = yield axios_1.default.post(url, data, header);
            return respons;
        }
        catch (error) {
            let errorMsg = '';
            if (!error.response) {
                errorMsg = ErrorMessages_1.Errors.noInternet;
            }
            else {
                if (!error.response.data.message) {
                    errorMsg = ErrorMessages_1.Errors.serverError;
                }
                else {
                    errorMsg = error.response.data.message;
                }
            }
            throw new Error(errorMsg);
        }
    });
}
